library(testthat)
library(contactdata) # nolint

test_check("contactdata")
